==> zio-aws-opensearch_2.13-5.17.172.2-sources.jar: zio/aws/opensearch/model/PackageVersionHistory.scala <==
package zio.aws.opensearch.model
import zio.aws.opensearch.model.primitives.{
  CreatedAt,
  CommitMessage,
  PackageVersion
}
import java.time.Instant
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import scala.jdk.CollectionConverters._
final case class PackageVersionHistory(
    packageVersion: Optional[PackageVersion] = Optional.Absent,
    commitMessage: Optional[CommitMessage] = Optional.Absent,
    createdAt: Optional[CreatedAt] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.opensearch.model.PackageVersionHistory = {
    import PackageVersionHistory.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.opensearch.model.PackageVersionHistory
      .builder()
      .optionallyWith(
        packageVersion.map(value =>
          PackageVersion.unwrap(value): java.lang.String
        )
      )(_.packageVersion)
      .optionallyWith(
        commitMessage.map(value =>
          CommitMessage.unwrap(value): java.lang.String
        )
      )(_.commitMessage)
      .optionallyWith(createdAt.map(value => CreatedAt.unwrap(value): Instant))(
        _.createdAt
      )
      .build()
  }
  def asReadOnly: zio.aws.opensearch.model.PackageVersionHistory.ReadOnly =
    zio.aws.opensearch.model.PackageVersionHistory.wrap(buildAwsValue())
}
object PackageVersionHistory {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.opensearch.model.PackageVersionHistory
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.opensearch.model.PackageVersionHistory =
      zio.aws.opensearch.model.PackageVersionHistory(
        packageVersion.map(value => value),
        commitMessage.map(value => value),
        createdAt.map(value => value)
      )
    def packageVersion: Optional[PackageVersion]
    def commitMessage: Optional[CommitMessage]
    def createdAt: Optional[CreatedAt]
    def getPackageVersion: ZIO[Any, AwsError, PackageVersion] =
      AwsError.unwrapOptionField("packageVersion", packageVersion)
    def getCommitMessage: ZIO[Any, AwsError, CommitMessage] =
      AwsError.unwrapOptionField("commitMessage", commitMessage)
    def getCreatedAt: ZIO[Any, AwsError, CreatedAt] =
      AwsError.unwrapOptionField("createdAt", createdAt)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.opensearch.model.PackageVersionHistory
  ) extends zio.aws.opensearch.model.PackageVersionHistory.ReadOnly {
    override val packageVersion: Optional[PackageVersion] =
      zio.aws.core.internal
        .optionalFromNullable(impl.packageVersion())
        .map(value => zio.aws.opensearch.model.primitives.PackageVersion(value))
    override val commitMessage: Optional[CommitMessage] = zio.aws.core.internal
      .optionalFromNullable(impl.commitMessage())
      .map(value => zio.aws.opensearch.model.primitives.CommitMessage(value))
    override val createdAt: Optional[CreatedAt] = zio.aws.core.internal
      .optionalFromNullable(impl.createdAt())
      .map(value => zio.aws.opensearch.model.primitives.CreatedAt(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.opensearch.model.PackageVersionHistory
  ): zio.aws.opensearch.model.PackageVersionHistory.ReadOnly = new Wrapper(impl)
}

==> zio-aws-opensearch_3-5.17.202.1-sources.jar: zio/aws/opensearch/model/PackageVersionHistory.scala <==
package zio.aws.opensearch.model
import zio.aws.opensearch.model.primitives.{
  CreatedAt,
  CommitMessage,
  PackageVersion
}
import java.time.Instant
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import scala.jdk.CollectionConverters.*
final case class PackageVersionHistory(
    packageVersion: Optional[PackageVersion] = Optional.Absent,
    commitMessage: Optional[CommitMessage] = Optional.Absent,
    createdAt: Optional[CreatedAt] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.opensearch.model.PackageVersionHistory = {
    import PackageVersionHistory.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.opensearch.model.PackageVersionHistory
      .builder()
      .optionallyWith(
        packageVersion.map(value =>
          PackageVersion.unwrap(value): java.lang.String
        )
      )(_.packageVersion)
      .optionallyWith(
        commitMessage.map(value =>
          CommitMessage.unwrap(value): java.lang.String
        )
      )(_.commitMessage)
      .optionallyWith(createdAt.map(value => CreatedAt.unwrap(value): Instant))(
        _.createdAt
      )
      .build()
  }
  def asReadOnly: zio.aws.opensearch.model.PackageVersionHistory.ReadOnly =
    zio.aws.opensearch.model.PackageVersionHistory.wrap(buildAwsValue())
}
object PackageVersionHistory {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.opensearch.model.PackageVersionHistory
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.opensearch.model.PackageVersionHistory =
      zio.aws.opensearch.model.PackageVersionHistory(
        packageVersion.map(value => value),
        commitMessage.map(value => value),
        createdAt.map(value => value)
      )
    def packageVersion: Optional[PackageVersion]
    def commitMessage: Optional[CommitMessage]
    def createdAt: Optional[CreatedAt]
    def getPackageVersion: ZIO[Any, AwsError, PackageVersion] =
      AwsError.unwrapOptionField("packageVersion", packageVersion)
    def getCommitMessage: ZIO[Any, AwsError, CommitMessage] =
      AwsError.unwrapOptionField("commitMessage", commitMessage)
    def getCreatedAt: ZIO[Any, AwsError, CreatedAt] =
      AwsError.unwrapOptionField("createdAt", createdAt)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.opensearch.model.PackageVersionHistory
  ) extends zio.aws.opensearch.model.PackageVersionHistory.ReadOnly {
    override val packageVersion: Optional[PackageVersion] =
      zio.aws.core.internal
        .optionalFromNullable(impl.packageVersion())
        .map(value => zio.aws.opensearch.model.primitives.PackageVersion(value))
    override val commitMessage: Optional[CommitMessage] = zio.aws.core.internal
      .optionalFromNullable(impl.commitMessage())
      .map(value => zio.aws.opensearch.model.primitives.CommitMessage(value))
    override val createdAt: Optional[CreatedAt] = zio.aws.core.internal
      .optionalFromNullable(impl.createdAt())
      .map(value => zio.aws.opensearch.model.primitives.CreatedAt(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.opensearch.model.PackageVersionHistory
  ): zio.aws.opensearch.model.PackageVersionHistory.ReadOnly = new Wrapper(impl)
}
